import 'bootstrap/dist/css/bootstrap.min.css';
import React from 'react';
import { CartProvider } from './context/CartContext';
import Footer from './components/Footer';
import CustomCarousel from './components/CustomCarousel';
import Contact from './components/Contact';
import Link from 'next/link';
import Script from 'next/script';

export const metadata = {
  title: 'الرئيسية',
};

const Layout: React.FC<{ children: React.ReactNode }> = ({ children }) => {
  return (
    <html lang="ar" dir="rtl">
      <head>
        <meta charSet="UTF-8" />
        <meta name="viewport" content="width=device-width, initial-scale=1.0" />
        <meta name="description" content="موقع اطلب ماتريد لشراء جميع المنتجات عبر الإنترنت" />
        <link rel="preconnect" href="https://fonts.googleapis.com" />
        <link rel="preconnect" href="https://fonts.gstatic.com" crossOrigin="anonymous" />
        <link href="https://fonts.googleapis.com/css2?family=Baloo+Bhaijaan+2:wght@700&display=swap" rel="stylesheet" />
      </head>
      <body style={{ background: '#f7f9fc' }}>
        <CartProvider>
          {/* Navbar */}
          <nav className="navbar navbar-expand-lg navbar-light bg-primary">
            <div className="container-fluid">
            <Link href="/" className="navbar-brand text-light" style={{ fontWeight: '700', fontSize: '26px' }}>
  اطلب ماتريد
</Link>
              <button
                className="navbar-toggler"
                type="button"
                data-bs-toggle="collapse"
                data-bs-target="#navbarNav"
                aria-controls="navbarNav"
                aria-expanded="false"
                aria-label="Toggle navigation"
              >
                <span className="navbar-toggler-icon"></span>
              </button>
              <div className="d-flex">
                <button className="btn btn-light" style={{ fontFamily: 'Baloo Bhaijaan 2' }}>
                  EN
                </button>
              </div>
            </div>
          </nav>

          {/* Carousel Section */}
          <CustomCarousel />

          {/* Page Content */}
          <div>{children}</div>

          {/* Contact Section */}
          <Contact />

          {/* Footer Section */}
          <Footer />
        </CartProvider>

        {/* Scripts */}
        <Script
          src="https://code.jquery.com/jquery-3.7.1.slim.js"
          integrity="sha256-UgvvN8vBkgO0luPSUl2s8TIlOSYRoGFAX4jlCIm9Adc="
          crossOrigin="anonymous"
          strategy="beforeInteractive"
        ></Script>
        <Script
          src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.bundle.min.js"
          integrity="sha384-YvpcrYf0tY3lHB60NNkmXc5s9fDVZLESaAA55NDzOxhy9GkcIdslK1eN7N6jIeHz"
          crossOrigin="anonymous"
          strategy="beforeInteractive"    
        ></Script>
      </body>
    </html>
  );
};

export default Layout;
